@@ -4,9 +4,9 @@ module Mocha
   
   module ParameterMatchers
 
-    # :call-seq: any_of -> parameter_matcher
+    # :call-seq: any_of(*parameter_matchers) -> parameter_matcher
     #
-    # Matches if any +matchers+ match.
+    # Matches if any +parameter_matchers+ match.
     #   object = mock()
     #   object.expects(:method_1).with(any_of(1, 3))
     #   object.method_1(1)
@@ -33,7 +33,7 @@ module Mocha
     
       def matches?(available_parameters)
         parameter = available_parameters.shift
-        @matchers.any? { |matcher| matcher.matches?([parameter]) }
+        @matchers.any? { |matcher| matcher.to_matcher.matches?([parameter]) }
       end
       
       def mocha_inspect
