@@ -28,7 +28,7 @@ module Mocha
       
       def matches?(available_parameters)
         parameter = available_parameters.shift
-        parameter.keys.include?(@key)
+        parameter.keys.any? { |key| @key.to_matcher.matches?([key]) }
       end
       
       def mocha_inspect
