@@ -14,7 +14,7 @@ class ParameterMatcherTest < Test::Unit::TestCase
   end
   
   def test_should_match_hash_parameter_with_specified_key
-    test_result = run_test do
+    test_result = run_as_test do
       mock = mock()
       mock.expects(:method).with(has_key(:key_1))
       mock.method(:key_1 => 'value_1', :key_2 => 'value_2')
@@ -23,7 +23,7 @@ class ParameterMatcherTest < Test::Unit::TestCase
   end
 
   def test_should_not_match_hash_parameter_with_specified_key
-    test_result = run_test do
+    test_result = run_as_test do
       mock = mock()
       mock.expects(:method).with(has_key(:key_1))
       mock.method(:key_2 => 'value_2')
@@ -32,7 +32,7 @@ class ParameterMatcherTest < Test::Unit::TestCase
   end
   
   def test_should_match_hash_parameter_with_specified_value
-    test_result = run_test do
+    test_result = run_as_test do
       mock = mock()
       mock.expects(:method).with(has_value('value_1'))
       mock.method(:key_1 => 'value_1', :key_2 => 'value_2')
@@ -41,7 +41,7 @@ class ParameterMatcherTest < Test::Unit::TestCase
   end
 
   def test_should_not_match_hash_parameter_with_specified_value
-    test_result = run_test do
+    test_result = run_as_test do
       mock = mock()
       mock.expects(:method).with(has_value('value_1'))
       mock.method(:key_2 => 'value_2')
@@ -50,7 +50,7 @@ class ParameterMatcherTest < Test::Unit::TestCase
   end
   
   def test_should_match_hash_parameter_with_specified_key_value_pair
-    test_result = run_test do
+    test_result = run_as_test do
       mock = mock()
       mock.expects(:method).with(has_entry(:key_1, 'value_1'))
       mock.method(:key_1 => 'value_1', :key_2 => 'value_2')
@@ -59,7 +59,7 @@ class ParameterMatcherTest < Test::Unit::TestCase
   end
 
   def test_should_not_match_hash_parameter_with_specified_key_value_pair
-    test_result = run_test do
+    test_result = run_as_test do
       mock = mock()
       mock.expects(:method).with(has_entry(:key_1, 'value_2'))
       mock.method(:key_1 => 'value_1', :key_2 => 'value_2')
@@ -68,7 +68,7 @@ class ParameterMatcherTest < Test::Unit::TestCase
   end
   
   def test_should_match_hash_parameter_with_specified_hash_entry
-    test_result = run_test do
+    test_result = run_as_test do
       mock = mock()
       mock.expects(:method).with(has_entry(:key_1 => 'value_1'))
       mock.method(:key_1 => 'value_1', :key_2 => 'value_2')
@@ -77,7 +77,7 @@ class ParameterMatcherTest < Test::Unit::TestCase
   end
 
   def test_should_not_match_hash_parameter_with_specified_hash_entry
-    test_result = run_test do
+    test_result = run_as_test do
       mock = mock()
       mock.expects(:method).with(has_entry(:key_1 => 'value_2'))
       mock.method(:key_1 => 'value_1', :key_2 => 'value_2')
@@ -86,7 +86,7 @@ class ParameterMatcherTest < Test::Unit::TestCase
   end
   
   def test_should_match_hash_parameter_with_specified_entries
-    test_result = run_test do
+    test_result = run_as_test do
       mock = mock()
       mock.expects(:method).with(has_entries(:key_1 => 'value_1', :key_2 => 'value_2'))
       mock.method(:key_1 => 'value_1', :key_2 => 'value_2', :key_3 => 'value_3')
@@ -95,7 +95,7 @@ class ParameterMatcherTest < Test::Unit::TestCase
   end
 
   def test_should_not_match_hash_parameter_with_specified_entries
-    test_result = run_test do
+    test_result = run_as_test do
       mock = mock()
       mock.expects(:method).with(has_entries(:key_1 => 'value_1', :key_2 => 'value_2'))
       mock.method(:key_1 => 'value_1', :key_2 => 'value_3')
@@ -104,7 +104,7 @@ class ParameterMatcherTest < Test::Unit::TestCase
   end
   
   def test_should_match_parameter_that_matches_regular_expression
-    test_result = run_test do
+    test_result = run_as_test do
       mock = mock()
       mock.expects(:method).with(regexp_matches(/meter/))
       mock.method('this parameter should match')
@@ -113,7 +113,7 @@ class ParameterMatcherTest < Test::Unit::TestCase
   end
 
   def test_should_not_match_parameter_that_does_not_match_regular_expression
-    test_result = run_test do
+    test_result = run_as_test do
       mock = mock()
       mock.expects(:method).with(regexp_matches(/something different/))
       mock.method('this parameter should not match')
@@ -122,7 +122,7 @@ class ParameterMatcherTest < Test::Unit::TestCase
   end
   
   def test_should_match_hash_parameter_with_specified_entries_using_nested_matchers
-    test_result = run_test do
+    test_result = run_as_test do
       mock = mock()
       mock.expects(:method).with(has_entries(:key_1 => regexp_matches(/value_1/), kind_of(Symbol) => 'value_2'))
       mock.method(:key_1 => 'value_1', :key_2 => 'value_2', :key_3 => 'value_3')
@@ -131,7 +131,7 @@ class ParameterMatcherTest < Test::Unit::TestCase
   end
   
   def test_should_not_match_hash_parameter_with_specified_entries_using_nested_matchers
-    test_result = run_test do
+    test_result = run_as_test do
       mock = mock()
       mock.expects(:method).with(has_entries(:key_1 => regexp_matches(/value_1/), kind_of(String) => 'value_2'))
       mock.method(:key_1 => 'value_2', :key_2 => 'value_3')
@@ -140,7 +140,7 @@ class ParameterMatcherTest < Test::Unit::TestCase
   end
   
   def test_should_match_parameter_that_matches_any_value
-    test_result = run_test do
+    test_result = run_as_test do
       mock = mock()
       mock.expects(:method).with(any_of('value_1', 'value_2')).times(2)
       mock.method('value_1')
@@ -150,7 +150,7 @@ class ParameterMatcherTest < Test::Unit::TestCase
   end
   
   def test_should_not_match_parameter_that_does_not_match_any_value
-    test_result = run_test do
+    test_result = run_as_test do
       mock = mock()
       mock.expects(:method).with(any_of('value_1', 'value_2'))
       mock.method('value_3')
@@ -159,7 +159,7 @@ class ParameterMatcherTest < Test::Unit::TestCase
   end
 
   def test_should_match_parameter_that_matches_all_values
-    test_result = run_test do
+    test_result = run_as_test do
       mock = mock()
       mock.expects(:method).with(all_of('value_1', 'value_1'))
       mock.method('value_1')
@@ -168,7 +168,7 @@ class ParameterMatcherTest < Test::Unit::TestCase
   end
   
   def test_should_not_match_parameter_that_does_not_match_all_values
-    test_result = run_test do
+    test_result = run_as_test do
       mock = mock()
       mock.expects(:method).with(all_of('value_1', 'value_2'))
       mock.method('value_1')
@@ -183,7 +183,7 @@ class ParameterMatcherTest < Test::Unit::TestCase
       end
     end
     duck = klass.new
-    test_result = run_test do
+    test_result = run_as_test do
       mock = mock()
       mock.expects(:method).with(responds_with(:quack, 'quack'))
       mock.method(duck)
@@ -198,7 +198,7 @@ class ParameterMatcherTest < Test::Unit::TestCase
       end
     end
     duck = klass.new
-    test_result = run_test do
+    test_result = run_as_test do
       mock = mock()
       mock.expects(:method).with(responds_with(:quack, 'quack'))
       mock.method(duck)
